@@ -1,5 +1,6 @@
 /*
- * The IKE Scanner (ike-scan) is Copyright (C) 2003 Roy Hills, NTA Monitor Ltd.
+ * The IKE Scanner (ike-scan) is Copyright (C) 2003-2004 Roy Hills,
+ * NTA Monitor Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +22,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: error.c,v 1.9 2003/02/21 17:42:25 rsh Exp $
+ * $Id: error.c,v 1.13 2004/01/02 09:30:36 rsh Exp $
  *
  * error.c -- error routines for IKE Scanner (ike-scan)
  *
@@ -32,6 +33,8 @@
 
 #include "ike-scan.h"
 
+static char rcsid[] = "$Id: error.c,v 1.13 2004/01/02 09:30:36 rsh Exp $"; /* RCS ID for ident(1) */
+
 int daemon_proc;	/* Non-zero if process is a daemon */
 
 /*
@@ -44,7 +47,7 @@ err_sys(const char *fmt,...) {
    va_start(ap, fmt);
    err_print(1, 0, fmt, ap);
    va_end(ap);
-   exit(1);
+   exit(EXIT_FAILURE);
 }
 
 /*
@@ -69,7 +72,7 @@ err_msg(const char *fmt,...) {
    va_start(ap, fmt);
    err_print(0, 0, fmt, ap);
    va_end(ap);
-   exit(1);
+   exit(EXIT_FAILURE);
 }
 
 /*
@@ -103,7 +106,7 @@ info_syslog(const char *fmt,...) {
 void
 err_print (int errnoflag, int level, const char *fmt, va_list ap) {
    int errno_save;
-   int n;
+   size_t n;
    char buf[MAXLINE];
 
    errno_save=errno;
@@ -122,3 +125,8 @@ err_print (int errnoflag, int level, const char *fmt, va_list ap) {
       fflush(stderr);
    }
 }
+
+void
+error_use_rcsid(void) {
+   printf("%s\n", rcsid);       /* Use rcsid to stop compiler optimising away */
+}
