@@ -1,5 +1,6 @@
 /*
- * The IKE Scanner (ike-scan) is Copyright (C) 2003 Roy Hills, NTA Monitor Ltd.
+ * The IKE Scanner (ike-scan) is Copyright (C) 2003-2004 Roy Hills,
+ * NTA Monitor Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +22,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: ike-scan.h,v 1.51 2003/11/13 09:22:41 rsh Exp $
+ * $Id: ike-scan.h,v 1.74 2004/01/10 18:22:04 rsh Exp $
  *
  * ike-scan.h -- Header file for IKE Scanner (ike-scan)
  *
@@ -29,6 +30,9 @@
  * Date:	12 September 2002
  */
 
+#ifndef IKE_SCAN_H
+#define IKE_SCAN_H 1
+
 /* Includes */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -41,6 +45,7 @@
 #include <ctype.h>
 #include <stdarg.h>
 #include <errno.h>
+#include <limits.h>
 #else
 #error This program requires the ANSI C Headers
 #endif
@@ -97,6 +102,10 @@
 #include <arpa/inet.h>
 #endif
 
+#ifdef HAVE_REGEX_H
+#include <regex.h>	/* Posix regular expression support */
+#endif
+
 #include "md5.h"
 #include "isakmp.h"
 
@@ -112,6 +121,7 @@
 #define DEFAULT_SOURCE_PORT 500		/* Default UDP source port */
 #define DEFAULT_DEST_PORT 500		/* Default UDP destination port */
 #define DEFAULT_LIFETIME 28800		/* Default lifetime in seconds */
+#define DEFAULT_LIFESIZE 0		/* Default lifesize in KB */
 #define DEFAULT_AUTH_METHOD 1		/* Default authentication method */
 #define DEFAULT_END_WAIT 60		/* Default time to wait at end in sec */
 #define DEFAULT_PATTERN_FUZZ 100	/* Default pattern fuzz in ms */
@@ -121,9 +131,12 @@
 #define SYSLOG 1			/* Use syslog if defined */
 #define SYSLOG_FACILITY LOG_USER	/* Syslog facility to use */
 #define PATTERNS_FILE "ike-backoff-patterns" /* Backoff patterns filename */
-#define MAX_PAYLOAD 13			/* Maximum defined payload number */
+#define VID_FILE "ike-vendor-ids"	/* Vendor ID patterns filename */
 #define EXPECTED_TOTAL 72		/* Expected ISAKMP header size total */
 
+#define STR_OR_ID(x, tab) \
+        (((x) < sizeof(tab)/sizeof(tab[0]) && tab[(x)]) ? tab[(x)] : numstr(x))
+
 /* Structures */
 struct host_entry {
    struct host_entry *prev;	/* Previous pointer */
@@ -151,12 +164,21 @@ struct pattern_entry_list {
 };
 
 struct pattern_list {
-   char *name;
-   int num_times;
-   struct pattern_entry_list *recv_times;
+   char *name;			/* Name of this backoff pattern */
+   unsigned num_times;		/* Number of time entries in this pattern */
+   struct pattern_entry_list *recv_times;	/* Pointer to list of times */
    struct pattern_list *next;
 };
 
+#ifdef HAVE_REGEX_H
+struct vid_pattern_list {
+   char *name;
+   char *pattern;	/* Text regular expression */
+   regex_t *regex;	/* Compiled regular expression */
+   struct vid_pattern_list *next;
+};
+#endif
+
 /* Functions */
 
 void err_sys(const char *, ...);
@@ -165,42 +187,72 @@ void err_msg(const char *, ...);
 void warn_msg(const char *, ...);
 void info_syslog(const char *, ...);
 void err_print(int, int, const char *, va_list);
-char *cpystr(char *string);
-void usage(void);
-void add_host(char *, unsigned);
-void send_packet(int, struct host_entry *, int, struct timeval *);
-int recvfrom_wto(int, char *, int, struct sockaddr *, int);
-void remove_host(struct host_entry *);
+void usage(int);
+void add_host_pattern(const char *, unsigned, unsigned *);
+void add_host(const char *, unsigned, unsigned *);
+void send_packet(int, unsigned char *, size_t, struct host_entry *, unsigned,
+                 struct timeval *);
+int recvfrom_wto(int, unsigned char *, size_t, struct sockaddr *, int);
+void remove_host(struct host_entry *, unsigned *);
 void timeval_diff(struct timeval *, struct timeval *, struct timeval *);
-void initialise_ike_packet(unsigned, int, int, int, unsigned char *, int,
-                           int, int, int);
-struct host_entry *find_host_by_cookie(struct host_entry *, char *, int);
-void display_packet(int, char *, struct host_entry *, struct in_addr *);
-void advance_cursor(void);
-void decode_transform(char *, int, int);
-void dump_list(void);
-void dump_times(int);
-void add_recv_time(struct host_entry *);
+unsigned char *initialise_ike_packet(size_t *, unsigned, unsigned, unsigned, unsigned,
+                                     unsigned, unsigned char *, size_t, int, int,
+                                     unsigned, int, unsigned char *, size_t);
+struct host_entry *find_host_by_cookie(struct host_entry *, unsigned char *,
+                                       int);
+void display_packet(int, unsigned char *, struct host_entry *,
+                    struct in_addr *, unsigned *, unsigned *, int, int);
+void advance_cursor(unsigned);
+void dump_list(unsigned);
+void dump_times(void);
+void add_recv_time(struct host_entry *, struct timeval *);
+void load_backoff_patterns(const char *, unsigned);
 void add_pattern(char *, unsigned);
+void load_vid_patterns(const char *);
+void add_vid_pattern(char *);
 char *match_pattern(struct host_entry *);
 int times_close_enough(struct timeval *, struct timeval *, unsigned);
 void dump_backoff(unsigned);
-void check_struct_sizes(void);
-unsigned int hstr_i(char *);
-struct isakmp_hdr* make_isakmp_hdr(uint8_t, uint8_t, uint32_t);
-struct isakmp_sa* make_sa_hdr(uint8_t, uint32_t);
-struct isakmp_proposal* make_prop(uint32_t, uint8_t);
-unsigned char* make_trans(int *, uint8_t, uint8_t, uint16_t,
-                          uint16_t, uint16_t, uint16_t, uint16_t,
-                          uint32_t);
-unsigned char* add_trans(int, int *, uint16_t, uint16_t, uint16_t, uint16_t,
-                         uint16_t, uint32_t);
-unsigned char* make_vid(int *, uint8_t, unsigned char *, int);
-unsigned char* add_vid(int, int *, unsigned char *, int);
-unsigned char* make_ke(int *, uint8_t, int);
-unsigned char* make_nonce(int *, uint8_t, int);
-unsigned char* make_id(int *, uint8_t, uint8_t, unsigned char *, int);
-int Gettimeofday(struct timeval *, struct timezone *);
+void dump_vid(void);
+unsigned int hstr_i(const char *);
+unsigned char* hex2data(const char *, size_t *);
+struct isakmp_hdr* make_isakmp_hdr(unsigned, unsigned, unsigned);
+struct isakmp_sa* make_sa_hdr(unsigned, unsigned);
+struct isakmp_proposal* make_prop(unsigned, unsigned);
+unsigned char* make_trans(size_t *, unsigned, unsigned, unsigned,
+                          unsigned, unsigned, unsigned, unsigned,
+                          unsigned, unsigned, int, unsigned char *, size_t);
+unsigned char* add_trans(int, size_t *, unsigned, unsigned, unsigned, unsigned,
+                         unsigned, unsigned, unsigned, int, unsigned char *,
+                         size_t);
+unsigned char* make_attr(size_t *, int, unsigned, size_t, unsigned, void *);
+unsigned char* add_attr(int, size_t *, int, unsigned, size_t, unsigned,
+                        void *);
+unsigned char* make_vid(size_t *, unsigned, unsigned char *, size_t);
+unsigned char* add_vid(int, size_t *, unsigned char *, size_t);
+unsigned char* make_ke(size_t *, unsigned, size_t);
+unsigned char* make_nonce(size_t *, unsigned, size_t);
+unsigned char* make_id(size_t *, unsigned, unsigned, unsigned char *, size_t);
+int Gettimeofday(struct timeval *);
 void *Malloc(size_t);
 void *Realloc(void *, size_t);
-void decode_trans(char *, int *, int *, int *, int *, int *);
+void decode_trans(char *, unsigned *, unsigned *, unsigned *, unsigned *,
+                  unsigned *);
+unsigned char *skip_payload(unsigned char *, size_t *, unsigned *);
+unsigned char *process_isakmp_hdr(unsigned char *, size_t *, unsigned *,
+                                  unsigned *);
+char *process_sa(unsigned char *, size_t, unsigned, int, int);
+char *process_attr(unsigned char **, size_t *);
+char *process_vid(unsigned char *, size_t, struct vid_pattern_list *);
+char *process_notify(unsigned char *, size_t);
+char *process_id(unsigned char *, size_t);
+char *make_message(const char *, ...);
+char *numstr(unsigned);
+char *printable(unsigned char*, size_t);
+char *hexstring(unsigned char*, size_t);
+/* The following functions are just to prevent rcsid being optimised away */
+void error_use_rcsid(void);
+void isakmp_use_rcsid(void);
+void wrappers_use_rcsid(void);
+
+#endif	/* IKE_SCAN_H */
